columns = ['id', 'title', 'original_title', 'original_title_romanised',
           'image', 'movie_banner', 'description', 'director',
           'producer', 'release_date', 'running_time', 'rt_score',
           'people', 'species', 'locations', 'vehicles', 'url'
           ]

# ----------------------------------------FOR INSERTION-----------------------------------

Value1 = {columns[0]: 'id_3', columns[1]: 'iuwrruy', columns[2]: 'iauf arhyrgfds',
          columns[3]: 'rhwouervh', columns[4]: 'some.jpg', columns[5]: 'other.jpg',
          columns[6]: 'a movie', columns[7]: 'argrghu', columns[8]: 'isrrig',
          columns[9]: 2021, columns[10]: 29, columns[11]: 80,
          columns[12]: 'a,list,of,people', columns[13]: 'Human', columns[14]: 'paris',
          columns[15]: 'car', columns[16]: 'uiwarrffurq'}

Value2 = {columns[0]: 'id_4', columns[1]: 'iuwzdffbgrruy', columns[2]: 'idfdggfds',
          columns[3]: 'rhsfgarrvh', columns[4]: 'sosfgde.jpg', columns[5]: 'ofgdaher.jpg',
          columns[6]: 'asdfdgvie', columns[7]: 'arsdgdghu', columns[8]: 'isadfdig',
          columns[9]: 2056, columns[10]: 79, columns[11]: 455,
          columns[12]: 'a,list,of,people', columns[13]: 'Human,cat', columns[14]: 'paris',
          columns[15]: 'car', columns[16]: 'uiwarrffurq'}

# Same id
Value3 = {columns[0]: 'id_2', columns[1]: 'vroom', columns[2]: 'vroom_romanised',
          columns[3]: 'rhsfgarrvh', columns[4]: 'sosfgde.jpg', columns[5]: 'ofgdaher.jpg',
          columns[6]: 'asdfdgvie', columns[7]: 'arsdgdghu', columns[8]: 'isadfdig',
          columns[9]: 2056, columns[10]: 79, columns[11]: 455,
          columns[12]: 'a,list,of,people', columns[13]: 'Human,cat', columns[14]: 'paris',
          columns[15]: 'car', columns[16]: 'uiwarrffurq'}

Value5 = {columns[0]: 'id_6', columns[1]: 'vroom', columns[2]: 'vroom_romanised',
          columns[3]: 'rhsfgarrvh', columns[4]: 'sosfgde.jpg', columns[5]: 'ofgdaher.jpg',
          columns[6]: 'asdfdgvie', columns[7]: 'arsdgdghu', columns[8]: 'isadfdig',
          columns[9]: '2056', columns[10]: 79, columns[11]: 455,
          columns[12]: 'a,list,of,people', columns[13]: 'Human,cat', columns[14]: 'paris',
          columns[15]: 'car', columns[16]: 'uiwarrffurq'}

Value4 = {columns[0]: 'id_5', columns[1]: 'vroom', columns[2]: 'vroom_romanised',
          columns[3]: 'rhsfgarrvh', columns[4]: 'sosfgde.jpg', columns[5]: 'ofgdaher.jpg',
          columns[6]: 'asdfdgvie', columns[7]: 'arsdgdghu', columns[8]: 'isadfdig'}

# columns[9]: 2056, columns[10]: 79, columns[11]: 455,
# columns[12]: 'a,list,of,people', columns[13]: 'Human,cat', columns[14]: 'paris',
# columns[15]: 'car', columns[16]: 'uiwarrffurq'}

# Extra column
Value6 = {columns[0]: 'id_7', columns[1]: 'vroom', columns[2]: 'vroom_romanised',
          columns[3]: 'rhsfgarrvh', columns[4]: 'sosfgde.jpg', columns[5]: 'ofgdaher.jpg',
          columns[6]: 'asdfdgvie', columns[7]: 'arsdgdghu', columns[8]: 'isadfdig',
          columns[9]: '2056', columns[10]: 79, columns[11]: 455,
          columns[12]: 'a,list,of,people', columns[13]: 'Human,cat', columns[14]: 'paris',
          columns[15]: 'car', columns[16]: 'uiwarrffurq', "extra": 456534}

# ------------------------------------------END--------------------------------------------
